==> APS_BlueSky_tools-0.0.6.tar.gz: APS_BlueSky_tools-0.0.6/README.md <==
# APS_BlueSky_tools

Various Python tools for use with BlueSky at the APS

[![Documentation Status](https://readthedocs.org/projects/aps-bluesky-tools/badge/?version=latest)](http://aps-bluesky-tools.readthedocs.io/en/latest/?badge=latest)
[![tag](https://img.shields.io/github/tag/BCDA-APS/APS_BlueSky_tools.svg)](https://github.com/BCDA-APS/APS_BlueSky_tools/tags)
[![release](https://img.shields.io/github/release/BCDA-APS/APS_BlueSky_tools.svg)](https://github.com/BCDA-APS/APS_BlueSky_tools/releases)
[![release](https://img.shields.io/pypi/v/APS_BlueSky_tools.svg)](https://pypi.python.org/pypi/APS_BlueSky_tools)
[![unit test](https://travis-ci.org/BCDA-APS/APS_BlueSky_tools.svg?branch=master)](https://travis-ci.org/BCDA-APS/APS_BlueSky_tools)
[![coverage](https://coveralls.io/repos/github/BCDA-APS/APS_BlueSky_tools/badge.svg?branch=master)](https://coveralls.io/github/BCDA-APS/APS_BlueSky_tools?branch=master)
[![code health](https://landscape.io/github/BCDA-APS/APS_BlueSky_tools/master/landscape.svg?style=plastic)](https://landscape.io/github/BCDA-APS/APS_BlueSky_tools/master)

* http://nsls-ii.github.io/
* https://github.com/NSLS-II/bluesky

## Provides

* `SpecWriterCallback()` : write SPEC data files from BlueSky
* ...

## Package Information

item              | description
------------------|--------------------------------
**author**        | Pete R. Jemian
**email**         | jemian@anl.gov
**copyright**     | 2017-, Pete R. Jemian
[**license**](APS_BlueSky_tools/LICENSE) | ANL OPEN SOURCE LICENSE
[**documentation**](https://APS_BlueSky_tools.readthedocs.io) | https://APS_BlueSky_tools.readthedocs.io
**source**        | https://github.com/BCDA-APS/APS_BlueSky_tools

==> APS_BlueSky_tools-0.0.10.tar.gz: APS_BlueSky_tools-0.0.10/README.md <==
# APS_BlueSky_tools

Various Python tools for use with BlueSky at the APS

[![Documentation Status](https://readthedocs.org/projects/aps-bluesky-tools/badge/?version=latest)](http://aps-bluesky-tools.readthedocs.io/en/latest/?badge=latest)
[![tag](https://img.shields.io/github/tag/BCDA-APS/APS_BlueSky_tools.svg)](https://github.com/BCDA-APS/APS_BlueSky_tools/tags)
[![release](https://img.shields.io/github/release/BCDA-APS/APS_BlueSky_tools.svg)](https://github.com/BCDA-APS/APS_BlueSky_tools/releases)
[![PyPi](https://img.shields.io/pypi/v/APS_BlueSky_tools.svg)](https://pypi.python.org/pypi/APS_BlueSky_tools)
[![conda](https://anaconda.org/prjemian/APS_BlueSky_tools/badges/version.svg)](https://anaconda.org/prjemian/APS_BlueSky_tools)
[![unit test](https://travis-ci.org/BCDA-APS/APS_BlueSky_tools.svg?branch=master)](https://travis-ci.org/BCDA-APS/APS_BlueSky_tools)
[![coverage](https://coveralls.io/repos/github/BCDA-APS/APS_BlueSky_tools/badge.svg?branch=master)](https://coveralls.io/github/BCDA-APS/APS_BlueSky_tools?branch=master)
[![code health](https://landscape.io/github/BCDA-APS/APS_BlueSky_tools/master/landscape.svg?style=plastic)](https://landscape.io/github/BCDA-APS/APS_BlueSky_tools/master)

* http://nsls-ii.github.io/
* https://github.com/NSLS-II/bluesky

## Provides

* `SpecWriterCallback()` : write SPEC data files from BlueSky
* ...

## Package Information

item              | description
------------------|--------------------------------
**author**        | Pete R. Jemian
**email**         | jemian@anl.gov
**copyright**     | 2017-, Pete R. Jemian
[**license**](APS_BlueSky_tools/LICENSE) | ANL OPEN SOURCE LICENSE
[**documentation**](https://APS_BlueSky_tools.readthedocs.io) | https://APS_BlueSky_tools.readthedocs.io
**source**        | https://github.com/BCDA-APS/APS_BlueSky_tools
